/*
 * University of Illinois/NCSA Open Source License
 *
 * Copyright  2015 NCSA.  All rights reserved.
 *
 * Developed by:
 *
 * Storage Enabling Technologies (SET)
 *
 * Nation Center for Supercomputing Applications (NCSA)
 *
 * http://www.ncsa.illinois.edu
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the .Software.),
 * to deal with the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 *    + Redistributions of source code must retain the above copyright notice,
 *      this list of conditions and the following disclaimers.
 *
 *    + Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimers in the
 *      documentation and/or other materials provided with the distribution.
 *
 *    + Neither the names of SET, NCSA
 *      nor the names of its contributors may be used to endorse or promote
 *      products derived from this Software without specific prior written
 *      permission.
 *
 * THE SOFTWARE IS PROVIDED .AS IS., WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS WITH THE SOFTWARE.
 */

#ifndef BLACKPEARL_DSI_H
#define BLACKPEARL_DSI_H

/*
 * Globus includes
 */
#include <globus_common.h>

/*
 * DS3 includes
 */

enum
{
    GRIDFTP_BLACKPEARL_TRACE             = 1<<0,
    GRIDFTP_BLACKPEARL_INFO              = 1<<1,
    GRIDFTP_BLACKPEARL_DS3               = 1<<2,
};

GlobusDebugDeclare(GLOBUS_GRIDFTP_BLACKPEARL);

#define GlobusBPDebugPrintf(_level, _message) \
do { \
    if (GlobusDebugTrue(GLOBUS_GRIDFTP_BLACKPEARL, _level)) \
    { \
        flockfile(GlobusDebugMyFile(GLOBUS_GRIDFTP_BLACKPEARL)); \
        GlobusDebugPrintf(GLOBUS_GRIDFTP_BLACKPEARL, _level, _message); \
        funlockfile(GlobusDebugMyFile(GLOBUS_GRIDFTP_BLACKPEARL)); \
    } \
} while (0)

#define GlobusBPEnter() \
    GlobusBPDebugPrintf( \
        GRIDFTP_BLACKPEARL_TRACE, \
        ("[%s] Entering\n", __func__))
        
#define GlobusBPExit() \
    GlobusBPDebugPrintf( \
        GRIDFTP_BLACKPEARL_TRACE, \
        ("[%s] Exiting\n", __func__))

#define GlobusBPExitWithError() \
    GlobusBPDebugPrintf( \
        GRIDFTP_BLACKPEARL_TRACE, \
        ("[%s] Exiting with error\n", __func__))


#endif /* BLACKPEARL_DSI_H */
